#!/bin/bash 
#
# produce REM.set file with scaling protocol for lambda-hopping/FEP+ emulation with ORAC
# 
# to activate this script make
# $ source source_this_file.bash in this dir 
if [ $#  -eq 0 ]; then
   echo " syntax: "
   echo " $ scaling.bash scale_factor nreplica [nbatteries]"
   echo ""
   echo "            where scal_factor is the scaling factor for the hot zone"
   echo "            nreplica is the number of replicas (must be EVEN) "
   echo "            and nbatteries is the number of REM replicates  "
   exit
fi

if [ -z $3  ] ; then
    batt=1
else
    batt=$3
fi

scale=$1
nrep=$2
nscal=`echo $nrep | awk '{print $1/2}'`
echo "Doing REM.set with S="$scale " Nrep=",$nrep " and repeats N_batt="$batt 

rm [xX].? >& /dev/null 
awk -v s=$1 -v n=$nscal 'BEGIN{for(i=1;i<=n;i++) printf "%15.6f\n", s^((i-1)/(n-1))}' /dev/null  > x.1
awk -v s=$1 -v n=$nscal 'BEGIN{for(i=1;i<=n;i++) printf "%15.6f\n", s^((i-1)/(n-1))}' /dev/null | tac > x.2
cat x.1 x.2 > X.1
cat x.1 x.2 > X.2
# lambda = 0.05 is the last state to be sampled
awk -v s=0.05 -v n=$nrep 'BEGIN{for(i=1;i<=n;i++) printf "%15.6f\n", s^((i-1)/(n-1))}' /dev/null  > X.3
echo "Scaling factors: " > REM.set 
echo "n.Ensemble      Bending+Bonding               Torsions+1-4                  Non-Bonded" >> REM.set

for i in `awk -v n=$batt 'BEGIN{for( i=1; i<=n; i++) {printf "%4d", i}}' /dev/null` ; do 
    (( jbeg=((i-1)*$nrep) ))
    paste X.1 X.2 X.3 | awk -v jb=$jbeg 'BEGIN{i=jb}{i++; printf "%10d%25.6f%25.5f%25.6f\n",  i, $1,$2,$3}' >> REM.set
done
rm [xX].? >& /dev/null 
exit 



